from setuptools import setup

setup(name='indies',
      version='0.1.1',
      description='Financial Indicators Library',
      url='https://github.com/miti0/indies',
      author='Miro Karpis',
      author_email='miroslav.karpis@gmail.com',
      license='Apache License 2.0',
      packages=['indies'],
      install_requires=[
          'numpy'
      ],
      zip_safe=False)
